# speedrun.py

An asynchronous API wrapper for speedrun.com

## Coverage

- [ ] Categories
- [ ] Games
- [ ] Guests
- [ ] Leaderboards
- [ ] Levels
- [ ] Notifications
- [ ] Platforms
- [ ] Profile
- [ ] Publishers
- [ ] Regions
- [ ] Runs
- [ ] Series
- [ ] Users
- [ ] Variables
